@@ -1357,7 +1357,8 @@ class Atlas:
             self.atlas = atlas
 
         def create_snapshot_for_cluster(self, cluster_name: str, retention_days: int = 7,
-                                        description: str = None, as_obj: bool = True) -> Union[CloudBackupSnapshot,dict]:
+                                        description: str = None, as_obj: bool = True) -> Union[
+            CloudBackupSnapshot, dict]:
             """
             Creates and on demand snapshot for the passed cluster
 
@@ -1375,7 +1376,7 @@ class Atlas:
                 .format(GROUP_ID=self.atlas.group, CLUSTER_NAME=cluster_name)
 
             try:
-                response = self.atlas.network.post(uri=Settings.BASE_URL + uri,payload=request_obj.as_dict)
+                response = self.atlas.network.post(uri=Settings.BASE_URL + uri, payload=request_obj.as_dict)
             except ErrAtlasBadRequest as e:
                 logger.warning('Received an Atlas bad request on Snapshot creation. Could be due to overlap')
                 raise IOError("Got a bad request error back from Atlas, this may be due to submitting"
@@ -1389,37 +1390,23 @@ class Atlas:
             if not as_obj:
                 return response
 
-        def get_backup_snapshots_for_cluster(self, cluster_name: str,
-                                             snapshot_id: Optional[str] = None, as_obj: bool = True) -> Union[
+        def get_backup_snapshots_for_cluster(self, cluster_name: str, as_obj: bool = True) -> Union[
             Iterable[CloudBackupSnapshot], Iterable[dict]]:
             """Get  backup snapshots for a cluster.
 
-            If not snapshot_id is provided, then all snapshots are retrieved.
-
-            If a snopshot id is provided, only one snapshot is returned.
 
             Retrieves
             url: https://docs.atlas.mongodb.com/reference/api/cloud-backup/backup/backups/
 
             Keyword Args:
                 cluster_name (str) : The cluster name to fetch
-                pageNum (int): Page number
-                itemsPerPage (int): Number of Users per Page
-                iterable (bool): To return an iterable high level object instead of a low level API response
 
             Returns:
                 AtlasPagination or dict: Iterable object representing this function OR Response payload
-
-            Raises:
-                ErrPaginationLimits: Out of limits
             """
-            if not snapshot_id:
-                uri = Settings.api_resources["Cloud Backup"]["Get all Cloud Backups for cluster"] \
-                    .format(GROUP_ID=self.atlas.group, CLUSTER_NAME=cluster_name)
-            if snapshot_id:
-                logger.warning('Getting by snapshotid')
-                uri = Settings.api_resources["Cloud Backup"]["Get snapshot by SNAPSHOT-ID"] \
-                    .format(GROUP_ID=self.atlas.group, CLUSTER_NAME=cluster_name, SNAPSHOT_ID=snapshot_id)
+
+            uri = Settings.api_resources["Cloud Backup"]["Get all Cloud Backups for cluster"] \
+                .format(GROUP_ID=self.atlas.group, CLUSTER_NAME=cluster_name)
 
             logger.debug(f"The cloudbackup uri used is {Settings.BASE_URL}{uri}")
 
@@ -1433,11 +1420,44 @@ class Atlas:
                 response_results: List[dict] = return_list
 
             if not as_obj:
-                if snapshot_id:
-                    return list(response_results)
-                else:
-                    for entry in response_results:
-                        yield entry
+                for entry in response_results:
+                    yield entry
+            if as_obj:
+                for entry in response_results:
+                    yield CloudBackupSnapshot.from_dict(entry)
+
+        def get_backup_snapshot_for_cluster(self, cluster_name: str,
+                                            snapshot_id: str, as_obj: bool = True) -> Union[
+            Iterable[CloudBackupSnapshot], Iterable[dict]]:
+            """Get  singe backup snapshot for a cluster.
+
+            Retrieves
+            url: https://docs.atlas.mongodb.com/reference/api/cloud-backup/backup/backups/
+
+            Keyword Args:
+                cluster_name (str) : The cluster name to fetch
+
+            Returns:
+                AtlasPagination or dict: Iterable object representing this function OR Response payload
+
+            """
+            logger.warning('Getting by snapshotid')
+            uri = Settings.api_resources["Cloud Backup"]["Get snapshot by SNAPSHOT-ID"] \
+                .format(GROUP_ID=self.atlas.group, CLUSTER_NAME=cluster_name, SNAPSHOT_ID=snapshot_id)
+
+            logger.debug(f"The cloudbackup uri used is {Settings.BASE_URL}{uri}")
+
+            response = self.atlas.network.get(Settings.BASE_URL + uri)
+            try:
+                response_results: List[dict] = response['results']
+            except KeyError:
+                return_list = list()
+                return_list.append(response)
+                response_results: List[dict] = return_list
+
+            if not as_obj:
+                return list(response_results)
+
             if as_obj:
                 for entry in response_results:
                     logger.debug(f'This is the cloud backup {entry}')
@@ -1445,7 +1465,7 @@ class Atlas:
 
         def is_existing_snapshot(self, cluster_name: str, snapshot_id: str) -> bool:
             try:
-                self.atlas.CloudBackups.get_backup_snapshots_for_cluster(cluster_name, snapshot_id)
+                self.atlas.CloudBackups.get_backup_snapshot_for_cluster(cluster_name, snapshot_id)
                 return True
             except ErrAtlasNotFound:
                 return False
@@ -1470,7 +1490,6 @@ class Atlas:
             else:
                 logger.info('The snapshot_id is valid')
 
-
             # Check if the source and target clusters are the same, if so raise exception unless override is True
 
             if source_cluster_name == target_cluster_name and not allow_same:
@@ -1483,10 +1502,10 @@ class Atlas:
             uri = Settings.api_resources["Cloud Backup Restore Jobs"]["Restore snapshot by cluster"] \
                 .format(GROUP_ID=self.atlas.group, CLUSTER_NAME=source_cluster_name)
 
-            request_obj = SnapshotRestore(delivery_type,snapshot_id,target_cluster_name,self.atlas.group)
+            request_obj = SnapshotRestore(delivery_type, snapshot_id, target_cluster_name, self.atlas.group)
 
             try:
-                response = self.atlas.network.post(uri=Settings.BASE_URL + uri,payload=request_obj.as_dict)
+                response = self.atlas.network.post(uri=Settings.BASE_URL + uri, payload=request_obj.as_dict)
             except ErrAtlasBadRequest as e:
                 logger.warning('Received an Atlas bad request on Snapshot restore request.')
                 raise IOError("Received an Atlas bad request on Snapshot restore request.")
@@ -1503,7 +1522,8 @@ class Atlas:
         def get_snapshot_restore_requests(self, cluster_name: str, restore_id: str = None, as_obj: bool = True):
 
             if not restore_id:
-                uri = Settings.api_resources["Cloud Backup Restore Jobs"]["Get all Cloud Backup restore jobs by cluster"] \
+                uri = Settings.api_resources["Cloud Backup Restore Jobs"][
+                    "Get all Cloud Backup restore jobs by cluster"] \
                     .format(GROUP_ID=self.atlas.group, CLUSTER_NAME=cluster_name)
             else:
                 logger.warning('Getting by snapshotid')
@@ -1532,6 +1552,7 @@ class Atlas:
                     logger.debug(f'This is the {entry}')
                     yield SnapshotRestoreResponse.from_dict(entry)
 
+
 class AtlasPagination:
     """Atlas Pagination Generic Implementation
 
